@@ -378,7 +378,7 @@ class VariableClBuilderLayeredSet(Variable):
         Проверить возможность ядра использовать overlay fs
         """
         return (
-            self.kernel_opt in self.Get('install.os_install_kernel_config'))
+            self.kernel_opt in self.Get('install.os_kernel_config'))
 
     def get(self):
         try:
@@ -429,7 +429,6 @@ class VariableClBuilderTarget(Variable):
         builder_disk_dev = self.Get('cl_builder_disk_dev')
         if not builder_disk_dev:
             return ""
-        build_id = self.Get('cl_builder_id')
         build_id_path = self.Get('cl_builder_id_path')
         mount_dir = path.join(distr.DefaultMountPath.BaseMountPath,
                               build_id_path)
